/**
 * Speech API
 * The OCI Speech Service harnesses the power of spoken language by allowing developers to easily convert file-based data containing human speech into highly accurate text transcriptions.
 * OpenAPI spec version: 20220101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Details related to the voice available for the given language code and voice type.
 */
export interface VoiceSummary {
    /**
     * Unique Id of the voice.
     */
    "voiceId": string;
    /**
     * A user-friendly display name of the language for the user.
     */
    "displayName": string;
    /**
     * A small description of the voice like its language and voice type.
     */
    "description"?: string;
    /**
     * Gender of the speaker.
     */
    "gender": VoiceSummary.Gender;
    /**
     * Models the particular speaker is aligned to.
     */
    "supportedModels"?: Array<string>;
    /**
     * An abbreviated notation of region to which the language and accent of the speaker belongs to.
     */
    "languageCode"?: VoiceSummary.LanguageCode;
    /**
     * A description of region to which the language and accent of the speaker belongs to.
     */
    "languageDescription"?: string;
    /**
     * The sample rate of the speaker in Hertz. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sampleRateInHertz": number;
    /**
     * The number of words the speaker can narrate per minute. It signifies the speed of the speech produced by the speaker. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "wordsPerMinute": number;
    /**
     * Whether this voice id is default voice used for inference.
     */
    "isDefaultVoice"?: boolean;
}
export declare namespace VoiceSummary {
    enum Gender {
        Male = "MALE",
        Female = "FEMALE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LanguageCode {
        EnUs = "en-US",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: VoiceSummary): object;
    function getDeserializedJsonObj(obj: VoiceSummary): object;
}
