/**
 * Oracle Delegate Access Control API
 * Oracle Delegate Access Control allows ExaCC and ExaCS customers to delegate management of their Exadata resources operators outside their tenancies.
With Delegate Access Control, Support Providers can deliver managed services using comprehensive and robust tooling built on the OCI platform.
Customers maintain control over who has access to the delegated resources in their tenancy and what actions can be taken.
Enterprises managing resources across multiple tenants can use Delegate Access Control to streamline management tasks.
Using logging service, customers can view a near real-time audit report of all actions performed by a Service Provider operator.

 * OpenAPI spec version: 20230801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Details of the Service Provider. Service provider offers services to the customer to support the delegated resources.
 *
 */
export interface ServiceProvider {
    /**
     * Unique identifier for the Service Provider.
     */
    "id": string;
    /**
     * The OCID of the compartment that contains the Delegation Control.
     */
    "compartmentId"?: string;
    /**
     * Unique name of the Service Provider.
     */
    "name": string;
    /**
     * Description of the Service Provider.
     *
     */
    "description"?: string;
    /**
     * Service Provider type.
     */
    "serviceProviderType": ServiceProvider.ServiceProviderType;
    /**
     * Types of services offered by this provider.
     */
    "serviceTypes": Array<ServiceProvider.ServiceTypes>;
    /**
     * Resource types for which this provider will provide service. Default to all if not specified.
     */
    "supportedResourceTypes": Array<ServiceProvider.SupportedResourceTypes>;
    /**
     * The current lifecycle state of the Service Provider.
     */
    "lifecycleState"?: ServiceProvider.LifecycleState;
    /**
     * Description of the current lifecycle state in more detail.
     */
    "lifecycleStateDetails"?: string;
    /**
     * Time when the Service Provider was created expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format, e.g. '2020-05-22T21:10:29.600Z'
     *
     */
    "timeCreated"?: Date;
    /**
     * Time when the Service Provider was last modified expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format, e.g. '2020-05-22T21:10:29.600Z'
     *
     */
    "timeUpdated"?: Date;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ServiceProvider {
    enum ServiceProviderType {
        OracleProvided = "ORACLE_PROVIDED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ServiceTypes {
        Troubleshooting = "TROUBLESHOOTING",
        AssistedPatching = "ASSISTED_PATCHING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SupportedResourceTypes {
        Vmcluster = "VMCLUSTER",
        Cloudvmcluster = "CLOUDVMCLUSTER",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ServiceProvider): object;
    function getDeserializedJsonObj(obj: ServiceProvider): object;
}
