/**
 * Oracle Delegate Access Control API
 * Oracle Delegate Access Control allows ExaCC and ExaCS customers to delegate management of their Exadata resources operators outside their tenancies.
With Delegate Access Control, Support Providers can deliver managed services using comprehensive and robust tooling built on the OCI platform.
Customers maintain control over who has access to the delegated resources in their tenancy and what actions can be taken.
Enterprises managing resources across multiple tenants can use Delegate Access Control to streamline management tasks.
Using logging service, customers can view a near real-time audit report of all actions performed by a Service Provider operator.

 * OpenAPI spec version: 20230801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Information about the new Delegation Control.
 */
export interface UpdateDelegationControlDetails {
    /**
     * Name of the Delegation Control. The name does not need to be unique.
     */
    "displayName"?: string;
    /**
     * Description of the Delegation Control.
     */
    "description"?: string;
    /**
     * number of approvals required. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "numApprovalsRequired"?: number;
    /**
     * List of Delegation Subscription OCID that are allowed for this Delegation Control. The allowed subscriptions will determine the available Service Provider Actions. Only support operators for the allowed subscriptions are allowed to create Delegated Resource Access Request.
     */
    "delegationSubscriptionIds"?: Array<string>;
    /**
     * Set to true to allow all Delegated Resource Access Request to be approved automatically during maintenance.
     */
    "isAutoApproveDuringMaintenance"?: boolean;
    /**
     * The OCID of the selected resources that this Delegation Control is applicable to.
     */
    "resourceIds"?: Array<string>;
    /**
     * List of pre-approved Service Provider Action names. The list of pre-defined Service Provider Actions can be obtained from the ListServiceProviderActions API. Delegated Resource Access Requests associated with a resource governed by this Delegation Control will be
     * automatically approved if the Delegated Resource Access Request only contain Service Provider Actions in the pre-approved list.
     *
     */
    "preApprovedServiceProviderActionNames"?: Array<string>;
    /**
     * The OCID of the OCI Notification topic to publish messages related to this Delegation Control.
     */
    "notificationTopicId"?: string;
    /**
     * The format of the OCI Notification messages for this Delegation Control.
     */
    "notificationMessageFormat"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace UpdateDelegationControlDetails {
    function getJsonObj(obj: UpdateDelegationControlDetails): object;
    function getDeserializedJsonObj(obj: UpdateDelegationControlDetails): object;
}
